2026-10-09 APP 2.0.0-beta48 has been released !
This is mainly a bug fix release for the reported bugs in beta47. In addition it has a significant User Interface performance improvement noticable when you need to process 1000s of images in APP.
2026-10-03 APP 2.0.0-beta47 has been released !
This is a very big release... many code optimizations/rewrites, many parts of APP are much faster and more precise, especially star analysis and registration are much faster ! Big mosaics will go much faster 🙂
And we introduce a new preview filter, which includes the new Adaptive Deep Sky Stretch and a General Levels Stretch, this has been long over due. The old preview filter (the panel on the right side to stretch and preview your data) has not been updated for a couple of years and it is a critical part of any APP session.
Adaptive Deep Sky Stretch or ADSS is a much more intuitive stretch algorithm. It is also color preserving (which is a great new addition in itself ! ) which means that the highlights are no longer bleached, color is maintained from the linear data while stretching. You can simply stretch your data using the sky background level and signal width sliders which work much easier and more intuitive. You no longer need to fiddle with the old complicated sliders with zoom buttons. All the zoom buttons for the sliders are made redundant. And you can enter slider values in the slider value fields yourself. I will make a youtube video in the coming days to explain and fully introduce ADSS. Once the video is ready, it will be highlighted on the forum.
RGB Combine upgrade !. The RGB Combine Tool has been rewritten mostly. The tool is faster and easier to use and most importantly, the Luminance slider to inject a luminance channel or channels into the RGB composite is now working correctly. It no longer bleaches the RGB colors. Combined with the new ADSS preview, you will get much better and easier great composites with great color! I will also explain this in a new youtube video.
Version beta2, but older versions are not different.
I noticed, that "Analyse Stars" takes ages when I use darks (need them for slight amp-glow).
W/o darks this task only needs 1 to 3 minutes per frame.
This slow progress is not always with darks but very often.
The Ha - lights and darks where taken using a Pentax K30.
Mmm interesting, didn't hear specifically about that yet. What system and specs do you use? And do you have some files with and without specific darks that show this issue? Would be nice to check that.
Yes, I can provide files that exihibit this behaviour (fast w/o darks, slow w darks)
My Sys Specs:
Lenovo T510, SSD
Intel(R) Core(TM) i7 CPU M 620 @ 2.67GHz 2.67 GHz
RAM 6,00 GB (5,86 GB verwendbar)
Windows 10, 64-Bit-Betriebssystem, x64-basierter Prozessor
Thanks, it may be that the delay is due to the calibration with darks first, but I wouldn't expect it to slow down after that. Can you upload like 10 subs and darks which show you this behaviour to our server?
Go to https://upload.astropixelprocessor.com and use upload1 as username and upload1 as password.
Create a directory named “aaronr-slowregistering” and upload in there. Thank you!
@vincent-mod Done, but named it "aaronr_slowstaranalysis" because that was the slow task.
Current analysis still running (16:24) since 8:30, finished 31 of 47 frames.
Ah yes, good one. 🙂 I'll have a look today or tomorrow, thanks.
